@@ -1,4 +1,5 @@
 import logging
+import os
 import socket
 import time
 from threading import Thread
@@ -40,24 +41,34 @@ MAX_LISTENING_PORT = 6889
 MAX_PEERS = 12
 REQUEST_INTERVAL = 0.2
 ITERATION_SLEEP_INTERVAL = 0.001
+LOGGING_NONE = 100
+
+logging.basicConfig(level=logging.DEBUG,
+                    format='%(asctime)s.%(msecs)03d %(levelname)s %(module)s - %(funcName)s: %(message)s',
+                    datefmt='%Y-%m-%d %H:%M:%S'
+                    )
 
 
-class BitTorrentClient:
+class TorrentClient:
     def __init__(
-        self, torrent, max_peers=MAX_PEERS, no_progress_bar=False, peers_file=None
+            self, torrent: str, max_peers: int = MAX_PEERS, use_progress_bar: bool = True, peers_file: str = None,
+            output_dir: str = '.'
     ):
         self.peer_manager: PeersManager = PeersManager(max_peers)
         self.tracker_manager: TrackerManager
         self.id: bytes = generate_peer_id()
         self.listener_socket: socket.socket = socket.socket()
         self.port: int = LISTENING_PORT
-        self.peers_file = peers_file
+        self.peers_file: str = peers_file
         self.pieces: List[Piece] = []
         self.should_continue = True
-        self.use_progress_bar = not no_progress_bar
+        self.use_progress_bar = use_progress_bar
+        if use_progress_bar:
+            logging.getLogger("BitTorrent").setLevel(LOGGING_NONE)
+
         # decode the config file and assign it
         self.torrent = TorrentFile(torrent)
-        self.piece_manager = DiskManager("{}.written".format(self.torrent.file_name))
+        self.piece_manager = DiskManager(output_dir, self.torrent)
         # create tracker for each url of tracker in the config file
         trackers = []
         if "announce" in self.torrent.config:
@@ -86,7 +97,7 @@ class BitTorrentClient:
             if len(peers) == 0:
                 raise Exception("No peers found")
 
-        logging.getLogger("BitTorrent").critical(f"Number of peers: {len(peers)}")
+        logging.getLogger("BitTorrent").info(f"Number of peers: {len(peers)}")
 
         self.peer_manager.add_peers(peers)
         handshakes = Thread(
@@ -104,8 +115,8 @@ class BitTorrentClient:
     def progress_download(self):
         if self.use_progress_bar:
             for _ in progress.track(
-                range(len(self.pieces)),
-                description=f"Downloading {self.torrent.file_name}",
+                    range(len(self.pieces)),
+                    description=f"Downloading {self.torrent.file_name}",
             ):
                 self.handle_messages()
         else:
@@ -124,7 +135,7 @@ class BitTorrentClient:
                 time.sleep(2)
                 continue
             except socket.error as e:
-                logging.getLogger("BitTorrent").critical(f"Unknown socket error: {e}")
+                logging.getLogger("BitTorrent").info(f"Unknown socket error: {e}")
                 continue
 
             for peer, message in messages.items():
@@ -145,6 +156,7 @@ class BitTorrentClient:
                     peer.set_choked()
 
                 elif type(message) is Unchoke:
+                    logging.getLogger("BitTorrent").debug(f"Received unchoke from {peer}")
                     peer.set_unchoked()
 
                 elif type(message) is PieceMessage:
@@ -167,9 +179,9 @@ class BitTorrentClient:
 
         while self.should_continue:
             self.request_current_block()
-            time.sleep(ITERATION_SLEEP_INTERVAL) # wait between each piece request
+            time.sleep(ITERATION_SLEEP_INTERVAL)  # wait between each piece request
 
-        logging.getLogger("BitTorrent").critical(f"Exiting the requesting loop...")
+        logging.getLogger("BitTorrent").info(f"Exiting the requesting loop...")
         self.piece_manager.close()
 
     def request_current_block(self):
@@ -186,9 +198,6 @@ class BitTorrentClient:
                 continue
 
             except PieceIsFull:
-                logging.getLogger("BitTorrent").debug(
-                    f"All blocks of piece {piece.index} are full, writing to disk..."
-                )
                 continue
 
             except NoPeersHavePiece:
@@ -237,14 +246,13 @@ class BitTorrentClient:
             block = piece.get_block_by_offset(pieceMessage.offset)
             block.data = pieceMessage.data
             block.status = BlockStatus.FULL
-            logging.getLogger('BitTorrent').debug(f'Successfully got block of piece {piece.index}')
 
             if piece.is_full():
                 self.piece_manager.write_piece(piece, self.torrent.piece_size)
                 self.pieces.remove(piece)
                 if not self.use_progress_bar:
-                    Utils.console.print(
-                        "[green]Progress: {have}/{total} Unchoked peers: {peers_have}/{total_peers}".format(
+                    logging.getLogger("BitTorrent").info(
+                        "Progress: {have}/{total} Unchoked peers: {peers_have}/{total_peers}".format(
                             have=self.piece_manager.written,
                             total=self.number_of_pieces,
                             peers_have=self.peer_manager.num_of_unchoked,
